@@ -25,14 +25,8 @@ class ReleasePostPaidInstanceRequest(RpcRequest):
 		RpcRequest.__init__(self, 'Ens', '2017-11-10', 'ReleasePostPaidInstance','ens')
 		self.set_method('POST')
 
-	def get_Version(self):
-		return self.get_query_params().get('Version')
-
-	def set_Version(self,Version):
-		self.add_query_param('Version',Version)
-
-	def get_InstanceId(self):
+	def get_InstanceId(self): # String
 		return self.get_query_params().get('InstanceId')
 
-	def set_InstanceId(self,InstanceId):
-		self.add_query_param('InstanceId',InstanceId)
\ No newline at end of file
+	def set_InstanceId(self, InstanceId):  # String
+		self.add_query_param('InstanceId', InstanceId)
